# TextualDon
A Mastodon client built with the Textual framework for Python.

### Current version: 0.1.0

![Demo Image](https://raw.githubusercontent.com/edward-jazzhands/textualdon/refs/heads/master/graphic1.png)

TextualDon aims to be a full-featured, graphical Mastodon client that lives inside of your terminal.

It offers a new take on 'social media in the terminal' compared to other apps. 
TextualDon leverages the full power of Textual to provide an almost website-like 
experience in a keyboard-centric TUI format.

## Get started:

Fast-start for uv users:
`uvx textualdon`

Recommended way to install: pipx, or uv as tool

`pipx install textualdon`

`uv tool install textualdon`

...then simply run with: `textualdon`

### Features:

- For keyboard lovers: Designed for 100% keyboard control (Or just mouse, or a mix).
- Cross-platform: Works across Windows, Mac, and Linux.
- Auto login and load specific pages on launch
- Support for images (And option to disable downloading them entirely).
- Looks good in most default Textual themes
- Many more to come

This app is in early Alpha stages. Many essential features are not built yet.   
This is only public to get feedback from advanced users. If you choose to use it, 
please keep in mind the app is not finished.